<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Str;
use App\Transaction;
use App\BusinessType;
use Auth;
use Illuminate\Support\Facades\Validator;

class NewIssuanceController extends Controller
{
    public function create(){
       
            $loc = session()->get('location');
      
        
       $businesstype = BusinessType::where('location_id', $loc)->orderBy('business_type')->get();
        $locations = DB::table('location')->where('location_id', $loc)->first();
        $barangays = DB::table('barangay')->where('location_id', $loc)->orderBy('barangay_name', 'asc')->get();
        $data = [
            'business_type' => $businesstype, 
            'barangay' => $barangays,
            'location' => $locations
        ];
        return view('issuances.new')->with($data);
    }

    public function getMatrix($area, $location){
        $matrix = DB::table('matrix')
                ->where('sqm_from', '<=', $area)
                ->where('sqm_to', '>=', $area)
                ->where('location_id', $location)
                ->get();
        return $matrix;
    }

    public function getAgent($location, $insurer){
        $agent = DB::table('agent')
                ->where('location_id', $location)
                ->where('insurer_id', $insurer)
                ->where('code', 'epayment')
                ->first();
        return $agent;
    }

    public function store(Request $request){
       $validator =  Validator::make($request->all(), [
            'business_name' => 'required',
            'business_address' => 'required',
            'barangay' => 'required',
            'business_type' => 'required',
            'area' => 'required|numeric|min:0|'
        ]);

        if ($validator->fails()) {
            if($request->input('renew')!='' or $request->input('renew')!=null){
               
                $policy_id = $request->input('renew');
                $string = 'cglisss'.$policy_id;
                $auth =  sha1($string);
            
                return redirect('result/'.$auth.'/'.$policy_id)
                        ->withErrors($validator)
                        ->withInput();
            }
            return redirect('/new')
                        ->withErrors($validator)
                        ->withInput();
        }
        
        $loc = $request->session()->get('location');

       

        $last_inc = Transaction::where('location_id', $loc)->max('increment');
        $increment = $last_inc + 1;

        $remainder = $increment % 7;

        switch ($remainder) {
            case 0:
                $insurer = 1; //1
                break;
            case 1:
                $insurer = 25; //2
                break;
            case 2:
                $insurer = 6; //29
                break;
            case 3:
                $insurer = 6; //27
                break;
            case 4:
                $insurer = 25; //31
                break;
            case 5:
                $insurer = 25; //25
                break;
            case 6:
                $insurer = 6; //6
                break;
            default:
              $insurer = 1;
          }
   
        
        $loc_code = DB::table('location')->where('location_id', $loc)->first();
      
        $area = $request->input('area');
        $matrix = $this->getMatrix($area, $loc);
        $agent = $this->getAgent($loc, $insurer);

        $new = new Transaction();
        $new->increment = $increment;
        $new->certificate_no = 'COI'.$loc_code->location_code.date('y').'-'.$increment;
        $new->policy_prefix = "";

        $new->policy_no = "";   //from setup policy no for online transaction
        $new->insurer_id = $insurer; //stronghold
        $new->agent_id = $agent->agent_id; //create agent for online transaction
        $new->business_name = $request->input('business_name');
        $new->business_address = $request->input('business_address');
        $new->barangay = $request->input('barangay');
        $new->area = $area;

        $new->inception_date = '1960-01-01'; //'date('Y-m-d')';
        $new->expiry_date = '1960-01-01'; //date('Y-m-d', strtotime('+1 years'));;
        $new->businesstype_id = $request->business_type;
        $type = DB::table('business_types')->where('businesstype_id', $request->business_type)->first();
        if($type->tag == 'High Risk'){
            $premium = $matrix[0]->tot_prem*2;
            $dst = $matrix[0]->doc_stamps*2;
            $vat = $matrix[0]->evat*2;
            $lgt = $matrix[0]->lgt*2;
        }else{
            $premium = $matrix[0]->tot_prem;
            $dst = $matrix[0]->doc_stamps;
            $vat = $matrix[0]->evat;
            $lgt = $matrix[0]->lgt;
        }
        $new->total_sum_insured = $matrix[0]->tot_sumIns;
        $new->total_premium = $premium;
        $new->doc_stamps = $dst;
        $new->vat = $vat;
        $new->lgt = $lgt;
        
        $new->to_less_in = $agent->to_less_in;
        $new->percentage = $agent->percentage;
        $token = Str::random(8);
        $new->transaction_code = $token;
        $new->user_id = 0; 
        
        if (Auth::check()){
            $euser_id = Auth::user()->euser_id;
        }else{
            $euser_id = 0;
        }
        $new->euser_id = $euser_id;
        $new->email = '';
        $new->contact_no = '';
        
        $new->location_id = $loc;
        $new->certificate_type = "COI";
        $new->is_bulk = 0;
        $new->cancel = 1;
        $new->atSixty = "false";
        $new->save();
        $transaction_id = $new->transaction_id;

        $digest = sha1('wilmargopole:'.$transaction_id);
        session()->put('token', $token);
        return redirect('payment-method/'.$token.'/'.$digest.'/'.$transaction_id);
    }
    
}
