<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;
use App\PolicySeries;

class SeriesMaintenanceController extends Controller
{
    public function show(){
        $location = DB::table('location')->orderBy('location_description')->get();
        
        $series = DB::table('policy_series')
                    ->rightJoin('agent', 'policy_series.agent_id', '=', 'agent.agent_id')
                    ->rightJoin('location', 'agent.location_id', '=', 'location.location_id')
                    ->rightJoin('insurer', 'agent.insurer_id', '=', 'insurer.insurer_id')
                    ->where('code', 'epayment')
                    ->get();
        //return response($series);
        $policy =[];
        foreach($series as $ser){
            $from = $ser->policy_from;
            $to = $ser->policy_to;
            $inventory = $this->policyInventory($from, $to,$ser->insurer_id);
            array_push($policy,[
                'series_id' => $ser->policy_series_id,
                'location_name' => $ser->location_description,
                'insurer' => $ser->insurer_name,
                'policy_from' => $from,
                'policy_to' => $to,
                'total' => $inventory['total'],
                'used' => $inventory['used'],
                'available' => $inventory['available'],
                'status' => $ser->e_status
            ]);
            
        }
        //return response($policy);
        $data = [
            'location' => $location,
            'series' => json_decode(json_encode($policy))
        ];
        return view('maintenance.series')->with($data);
       // return response($data);
    }

    public function getMemberInsurerPerLocation($loc){
        $insurer['data'] = DB::table('insurer')
                    ->orderBy('insurer_name')
                    ->rightJoin('member_insurer','insurer.insurer_id', '=', 'member_insurer.insurer_id')
                    ->where('location_id', $loc)
                    ->get();
        echo json_encode($insurer);
        exit;
    }

    public function store(Request $request){
        $validator =  Validator::make($request->all(), [
            'location' => 'required',
            'insurer' => 'required',
            'policy-from' => 'required|numeric',
            'policy-to' => 'required|numeric'
        ],[
            'required' => 'This field is required',
            'numeric' => 'Numeric field.'
        ]);

        if ($validator->fails()) {
            return redirect('/maintenance/series')
                        ->withErrors($validator)
                        ->withInput();
        }
        $loc = $request->input('location');
        $insurer = $request->input('insurer');
        $from = $request->input('policy-from');
        $to = $request->input('policy-to');
        $duplicatePolicy = DB::select('select * from policy_series where (insurer_id = '.$insurer.' and policy_from <='.$from.' and policy_to >='.$to.') or (insurer_id='.$insurer.' and policy_from <='.$to.' and policy_to >='.$from.')');
        
        if($duplicatePolicy){
            return redirect('maintenance/series')->with('message', 'Policy numbers already exist.');
        }else{
            $agent = DB::table('agent')->where(['location_id' => $loc, 'insurer_id' => $insurer, 'code' => 'epayment'])->first();

            $series = new PolicySeries();
            $series->insurer_id = $insurer;
            $series->agent_id = $agent->agent_id;
            $series->prefix = "";
            $series->policy_from = $from;
            $series->policy_to = $to;
            $series->e_status = "";
            $series->date_created = date('Y-m-d H:i:s');
            $series->user_id = 1;
            $series->save();
            return redirect('maintenance/series')->with('success', 'Successfully saved.');
        }

    }

    public function policyInventory($from, $to, $insurer){
        $from = (int)$from;
        $to = (int)$to;
        $transactions = DB::table('transaction')
                        ->where('insurer_id', $insurer)
                        ->where('certificate_type', 'COI')
                        ->where('policy_no', '>=', $from)
                        ->where('policy_no', '<=', $to)
                        ->get();
        $usedPolicy = $transactions->count();
        $totalPolicies = $to - $from + 1;
        $availablePolicy = $totalPolicies - $usedPolicy;
        $data = ['total' => $totalPolicies, 'used' => $usedPolicy, 'available' => $availablePolicy];
        return $data;
    }

    public function tagSeries($seriesID){
        //get current series of location then untag
        $current = DB::table('policy_series')
                    ->where('policy_series_id', $seriesID)
                    ->first();
        $agent = $current->agent_id;

        $untag = DB::table('policy_series')
                    ->where('agent_id', $agent)
                    ->where('e_status', 'current')
                    ->update(['e_status' => '']);
        
        //tag series to be the current            
        $tag = DB::table('policy_series')
                    ->where('policy_series_id', $seriesID)
                    ->where('e_status', '')
                    ->update(['e_status' => 'current']);
        if($tag)
            return redirect('maintenance/series')->with('success', 'Successfully updated.');
        else
            return redirect('maintenance/series')->with('message', 'Error encountered.');
    }
}
