<?php

namespace App\Http\Controllers\Auth;

use App\User;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;
use Illuminate\Foundation\Auth\RegistersUsers;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Illuminate\Auth\Events\Registered;
use Mail;

class RegisterController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Register Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles the registration of new users as well as their
    | validation and creation. By default this controller uses a trait to
    | provide this functionality without requiring any additional code.
    |
    */

    use RegistersUsers;

    /**
     * Where to redirect users after registration.
     *
     * @var string
     */
    protected $redirectTo = '/login';

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        return Validator::make($data, [
            'firstname' => 'required|string|max:50',
            'lastname' => 'required|string|max:50',
            'mobile' => 'required|digits:10',
            'email' => 'required|string|email|max:255|unique:e_users',
            'password' => 'required|string|min:6|confirmed',
        ]);
    }

    /**
     * Create a new user instance after a valid registration.
     *
     * @param  array  $data
     * @return \App\User
     */
    protected function create(array $data)
    {
        return User::create([
            'firstname' => $data['firstname'],
            'lastname' => $data['lastname'],
            'mobile_no' => $data['mobile'],
            'email' => $data['email'],
            'password' => bcrypt($data['password']),
        ]);
    }

    protected function register(Request $request)
    {
        // $this->validator($request->all())->validate();

        // event(new Registered($user = $this->create($request->all())));

        // //$this->guard()->login($user);

        // return $this->registered($request, $user)
        //                 ?: redirect($this->redirectPath());
        $input = $request->all();
        // $validator = $this->validator($input);
        
        $validator = $this->validator($request->all())->validate();

        //if($validator->passes()){
            $data = $this->create($input)->toArray();

            $data['token'] = Str::random(25);
            
            $user = User::find($data['euser_id']);
            $user->token = $data['token'];
            $user->save();

            Mail::send('payment.mailbody', $data, function($message) use ($data) {
                $message->to($data['email']);
                $message->subject('Email Verification');
            }); 
            return redirect(route('login'))->with('status', 'Confirmation email has been sent. Kindly check your email.');
        //}
        //return redirect(route('register'))->with('status', $validator->errors());
    }

    public function confirmation($token){
        $user = User::where('token', $token)->first();

        if(!is_null($user)){
            $user->verified = 1;
            $user->token = '';
            $user->save();
            return redirect(route('login'))->with('status', 'Your activation is completed');
        }
        return redirect(route('login'))->with('status', 'Something went wrong');
    }
}