<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Transaction;
use Auth;
use Illuminate\Support\Facades\DB; 
use PDF;
use Crypt;
use QRCode;

class HomeController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $userId = Auth::user()->euser_id;
        $transactions = DB::table('transaction')
        ->select('*','transaction.transaction_id as id')
        ->leftjoin('dragonpay_logs', 'transaction.certificate_no', '=', 'dragonpay_logs.txnid')
        ->leftJoin('surety_bond_policies','transaction.transaction_id','=','surety_bond_policies.transaction_id')
        ->where('transaction.euser_id',$userId)
     
        ->get();
        return view('home')->with('transactions',$transactions);
    }
    
    public function download_policy($cert_no){
        $cert = Crypt::decryptString($cert_no);
        $getTrans = DB::table('transaction')->where('certificate_no', $cert)->first();
        $insurer_id = $getTrans->insurer_id;

        if($insurer_id == 1){
            // stronghold
            $file = "attachment/stronghold.pdf";
        }else if($insurer_id == 2){
            // sterling
            $file = "attachment/sterling.pdf";
        }else if($insurer_id == 29){
            // bethel
            $file = "attachment/bethel.pdf";
        }else if($insurer_id == 27){
            // milestone
            $file = "attachment/milestone.pdf";
        }else if($insurer_id == 31){
            // western
            $file = "attachment/western.pdf";
        }else if($insurer_id == 6){
            // alpha
            $file = "attachment/alpha.pdf";
        }else if($insurer_id == 25){
            // premier
            $file = "attachment/premier.pdf";
        }

        $headers = [
            'Content-Type' => 'application/pdf',
         ];

        return response()->download($file, $cert.' - Policy.pdf', $headers);
    }

    public function download_coi($cert_no){
        $cert = Crypt::decryptString($cert_no);
        $file= 'attachment/'.$cert.'.pdf';

        if(! file_exists($file)){
            $transact = DB::table('transaction')
                            ->rightJoin('e_users', 'e_users.euser_id', '=', 'transaction.euser_id')
                            ->rightJoin('location', 'location.location_id', '=', 'transaction.location_id')
                            ->rightJoin('agent', 'transaction.agent_id', '=', 'agent.agent_id')
                            ->join('insurer','agent.insurer_id','=','insurer.insurer_id')
                            ->where('certificate_no', $cert)
                            ->first();
        
            $this->createQr($transact->transaction_code);
            $data = [
                'policy_no' => $transact->policy_no,
                'transaction_date' => $transact->date_created,
                'business_name' => strtoupper($transact->business_name),
                'business_address' => strtoupper($transact->business_address),
                'inception' => date('m/d/Y',strtotime($transact->inception_date)),
                'expiry' => date('m/d/Y',strtotime($transact->expiry_date)),
                'area' => $transact->area,
                'sum_insured' => number_format($transact->total_sum_insured,"2",".",","),
                'premium' => number_format($transact->total_premium,"2",".",","),
                'dst' => number_format($transact->doc_stamps,"2",".",","),
                'vat' => number_format($transact->vat,"2",".",","),
                'lgt' => number_format($transact->lgt,"2",".",","),
                'total' => $transact->total_premium + $transact->doc_stamps + $transact->vat + $transact->lgt,
                'barangay' => strtoupper($transact->barangay),
                'location' => strtoupper($transact->location_description),
                'agent_code' => $transact->agent_code,
                'image' =>$transact->image,
                'signature' => $transact->signature,
                'position_name' => $transact->position_name,
                'position' => $transact->position,
                'certificate_no' => $transact->certificate_no,
                'security_code' => $transact->transaction_code

            ];
            $certificateNo = $transact->certificate_no;
            $path = 'attachment/'.$certificateNo.'.pdf';
            
            PDF::loadView('pdf.coi', $data)->setPaper('Letter', 'portrait')->save($path);
        }

        $headers = [
            'Content-Type' => 'application/pdf',
         ];

        return response()->download($file, $cert.' - COI.pdf', $headers);

    }

    public function createQr($security_code){
        $file = 'attachment/'.$security_code.'.png';
        return $qr = QRCode::text('http://www.cglis.com.ph/v2/Policy_status?transaction_code='.$security_code)
        ->setMargin(2)
        ->setOutFile($file)
        ->png();    
    }
}
