<?php

namespace App\Http\Controllers\Surety;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;
use Crypt;


use App\Transaction;
use Mail;

class SuretyBondController extends Controller
{

    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index($transaction_id){
        
        
        $transactionId = Crypt::decryptString($transaction_id);
        
        $loc = session()->get('location');
        $locations = DB::table('location')->where('location_id', $loc)->first();
        $data = [
            'location' => $locations,
            'transaction_id' => $transactionId
        ];
        return view('surety.breakdown')->with($data);
    }


    public function store(Request $request){

        $validator =  Validator::make($request->all(), [
            'id_description' => 'required',
            'id_number' => 'required',
            'issued_date' => 'required',
            'signatory' => 'required',
            'position' => 'required'
        ]);

        if ($validator->fails()) {
            
            return back()->withErrors($validator)->withInput();
        }
        

        $bondMatrix = DB::table('bond_matrix')->first();

        $premium = $bondMatrix->premium;
        $lgt = $bondMatrix->lgt;
        $docStamps = $bondMatrix->doc_stamps;
        $vat = $bondMatrix->vat;
        $notarialFee = $bondMatrix->notarial_fee;
        $ackFee = $bondMatrix->acknowledgement_fee;

        $transactionId = $request->input('transaction_id');
        $idDesc = $request->input('id_description');
        $idNumber = $request->input('id_number');
        $issuedDate = $request->input('issued_date');
        $signatory = $request->input('signatory');
        $position = $request->input('position');

        $transactionCode = Str::random(8);

        DB::table('surety_details')->insert(
            ['id_description' => $idDesc, 
             'id_number' => $idNumber,
             'id_issued_date' => $issuedDate,
             'transaction_id' => $transactionId,
             'premium' =>  $premium,
             'lgt'=> $lgt,
             'doc_stamps'  => $docStamps,
             'vat'  => $vat,
             'notarial_fee'  => $notarialFee,
             'acknowledgement_fee'  => $ackFee,
             'transaction_code' => $transactionCode,
             'signatory' => $signatory,
             'position' => $position,
             ]
        );

        $token = $transactionCode;
        $digest = sha1('wilmargopole:'.$transactionId);
        session()->put('token', $token);
       
        return redirect('surety-payment-method/'.$token.'/'.$digest.'/'.$transactionId);
    }

    public function paymentMethod($token,$digest,$id){

        $localDigest =  sha1('wilmargopole:'.$id);
            
        //check if the data is not altered in url
        if($localDigest==$digest){

            //update the transaction table to have its user
            $userId =  Auth::user()->euser_id;
          //  echo $userId;
            $affected = DB::table('transaction')
							->where('transaction_id', $id)
							->update(['euser_id' => $userId]);	


            $loc =  session()->get('location');
            $environment= Config::get('app.env');
            $locations = DB::table('location')->where('location_id', $loc)->first();

            if($environment == 'production'){
                $merchant_id = 'SICICGLI';
            }
            else{
                $merchant_id =  Config::get('dragonpay.test_merchant_id');
            }

            $transaction  = Transaction::find($id);
            $bondNo = 'Bond-'.$id;

            $bond = DB::table('surety_details')->where('transaction_id',$id)->first();
           // dd($bond);

            $totalAmountDue = $bond->premium + $bond->lgt + $bond->vat + $bond->doc_stamps + $bond->notarial_fee + $bond->acknowledgement_fee;
            $digest = sha1($merchant_id.$bondNo.$totalAmountDue.'PHP'.$transaction->business_name);

            $data = array(
                'transaction' => Transaction::find($id),
                'merchant_id' => $merchant_id,
                'location' =>$locations,
                'digest' => $digest
                
            );

            return view('surety.payment-method')->with($data);
            }else{
                echo "You are not allowed to view this page";
            }
    }

   
}
