<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\BusinessType;
use App\CavVerification;
use App\VerificationAttachment;
use DB;
use Validator;
use Illuminate\Support\Str;
use Auth;


class VerifyInsuranceController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');        
    }
    
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $loc = session()->get('location');
        $businesstype = BusinessType::where('location_id', $loc)->get();
        $locations = DB::table('location')->where('location_id', $loc)->first();
        $barangays = DB::table('barangay')->where('location_id', $loc)->orderBy('barangay_name', 'asc')->get();
        $insurers = DB::table('insurer')->orderBy('insurer_name')->get();
        $data = [
            'business_type' => $businesstype, 
            'barangay' => $barangays,
            'location' => $locations,
            'insurers' => $insurers,
            'verification_code' => Str::random(8)
        ];
        //return view('issuances.new')->with($data);
        return view('verification.details')->with($data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $validator =  Validator::make($request->all(), [
            'business_name' => 'required',
            'business_address' => 'required',
            'barangay' => 'required',
            'business_type' => 'required',
            'area' => 'required|numeric|min:0|',
            'insurer' => 'required',
            'policy_no' => 'required',
            'inception_date' => 'required|before:expiry_date',
            'expiry_date' => 'required|after:inception_date',
            'uploads' => 'required',
            'uploads.*' => 'file|max:10000',
        ],[
            'required' => 'This field is required.',
            'uploads.required' => 'No file selected.',
            'uploads.*.mimes' => 'Invalid file type.',
            'uploads.*.max' => 'Maximum file size of 10Mb'
        ]);

        if ($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }
        $code = $request->input('verification_code');
        $checkExistsCode = DB::table('cav_verification')->where('cav_verification_code', $code)->count();
        if($checkExistsCode == 0){
            $data = new CavVerification();
            $data->cav_verification_code = $code;
            $data->business_name = $request->input('business_name');
            $data->business_address = $request->input('business_address');
            $data->barangay = $request->input('barangay');
            $data->location_id = $request->session()->get('location');;
            $data->businesstype_id = $request->business_type;
            $data->area = $request->input('area');
            $data->insurer_id = $request->input('insurer');
            $data->policy_no = $request->input('policy_no');
            $data->inception_date = $request->input('inception_date');
            $data->expiry_date = $request->input('expiry_date');
            $data->euser_id = Auth::user()->euser_id;
            $data->status = 'pending';
            $data->save();
            $verification_id = $data->cav_verification_id;
        }

        if($request->hasFile('uploads')) {
            $allowedfileExtension=['pdf','jpg','png','jpeg','docx','doc'];
            $files = $request->file('uploads');
            foreach($files as $file){
                $extension = $file->getClientOriginalExtension();
                $check=in_array($extension,$allowedfileExtension);
                if($check){
                    foreach($request->uploads as $upload){
                        $fileName = date('Ymd').'_'.date('hi').'_'.$upload->getClientOriginalName();
                        $upload->move('../e-cglinsurance/cav_uploads', $fileName);
                        $fileModel = new VerificationAttachment();
                        $fileModel->attachment_file = date('Ymd').'_'.date('hi').'_'.$upload->getClientOriginalName();
                        $fileModel->attachment_path = '/cav_uploads/'.$fileName;
                        $fileModel->cav_verification_id = $verification_id;
                        $fileModel->euser_id = Auth::user()->euser_id;
                        $fileModel->save();
                    }
                    return redirect('/verification/pending/'.$data->cav_verification_code);
                }else{
                    return back()->withErrors(['uploads' => 'Invalid file type.'])->withInput();
                }
            }
        }
        
    }

    public function show($id){
        return view('verification.success');
    }

}
